@@ -1,9 +1,10 @@
 __all__ = ('ObjectPath', 'ByteArray', 'Signature', 'Byte', 'Boolean',
            'Int16', 'UInt16', 'Int32', 'UInt32', 'Int64', 'UInt64',
            'Double', 'String', 'Array', 'Struct', 'Dictionary',
-           'UTF8String')
+           'UTF8String', 'UnixFd')
 
 from _dbus_bindings import ObjectPath, ByteArray, Signature, Byte,\
                            Int16, UInt16, Int32, UInt32,\
                            Int64, UInt64, Dictionary, Array, \
-                           String, Boolean, Double, Struct, UTF8String
+                           String, Boolean, Double, Struct, UTF8String, \
+                           UnixFd
